PAWpySeed: pswf Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
pswf Struct Reference

`#include <utils.h>`

Collaboration diagram for pswf:
[legend]

## Public Attributes
int | num_elems
int | num_sites
ppot_t * | pps
int * | G_bounds
kpoint_t ** | kpts
int | nspin
int | nband
int | nwk
double * | lattice
double * | reclattice
int * | fftg
int | num_aug_overlap_sites
double * | dcoords
double complex ** | overlaps

## Member Data Documentation

double* pswf::dcoords

int* pswf::fftg

int* pswf::G_bounds

kpoint_t** pswf::kpts

double* pswf::lattice

int pswf::nband

int pswf::nspin

int pswf::num_aug_overlap_sites

int pswf::num_elems

int pswf::num_sites

int pswf::nwk

double complex** pswf::overlaps

ppot_t* pswf::pps

double* pswf::reclattice

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h